@@ -9,6 +9,9 @@ from . import utils as utils_command
 from . import cmd as cmd_command
 from . import print as print_command
 from . import data as data_command
+from . import fix as fix_command
+from . import fetch as fetch_command
+from . import git as git_command
 from .win32 import __entry__ as win32_command
 
 from ..typer import command_version
@@ -24,6 +27,9 @@ app.add_typer(utils_command.app, name='utils')
 app.add_typer(cmd_command.app, name='cmd')
 app.add_typer(print_command.app, name='print')
 app.add_typer(data_command.app, name='data')
+app.add_typer(fix_command.app, name='fix')
+app.add_typer(fetch_command.app, name='fetch')
+app.add_typer(git_command.app, name='git')
 app.add_typer(win32_command.app, name='win32')
 
 
