@@ -1,3 +1,7 @@
+import datetime
+from .func import FuncAnyArgs
+
+
 class classproperty:
     """
     Decorator that converts a method with a single cls argument into a property
@@ -27,6 +31,23 @@ def rect_split(total, col_max):
             return [col for _ in range(row - 1)] + [rest]
 
 
+def find(array, func, start=None, end=None, reverse=False):
+    start = 0 if start is None else max(0, start)
+    end = len(array) if end is None else min(end, len(array))
+    func = FuncAnyArgs(func)
+    r = range(start, end)
+    if reverse:
+        r = reversed(r)
+    for i in r:
+        if func(array[i], i, array):
+            return i
+    return -1
+
+
+def ns2datetime(t):
+    return datetime.datetime.fromtimestamp(t / 1000000000)
+
+
 if __name__ == '__main__':
     print(rect_split(13, 5))
     print(rect_split(11, 5))
