@@ -9,3 +9,11 @@ except ImportError as e:
         pass
     else:
         raise
+
+try:
+    from .split import *
+except ImportError as e:
+    if "'crc'" in e.args[0]:
+        pass
+    else:
+        raise
