@@ -1,5 +1,6 @@
 import os
 import uuid
+from itertools import chain
 
 
 def join_path(*args):
@@ -20,12 +21,15 @@ def new_empty_path(*paths):
             return np
 
 
-def path_ext(path):
-    filename = os.path.basename(path)
-    file, ext = os.path.splitext(filename)
+def split_ext(path):
+    file, ext = os.path.splitext(path)
     if not ext and file.startswith('.'):
-        return file
-    return ext
+        return '', file
+    return file, ext
+
+
+def path_ext(path):
+    return split_ext(path)[-1]
 
 
 def multi_ext(path, limit=None, case=False):
@@ -48,3 +52,15 @@ def multi_ext(path, limit=None, case=False):
         else:
             break
     return filename, result
+
+
+def where(x, path=None):
+    if path:
+        paths = [path]
+    else:
+        paths = chain(iter([os.getcwd()]), iter(os.environ['PATH'].split(os.pathsep)))
+    for p in paths:
+        fp = os.path.join(p, x)
+        if os.path.exists(fp):
+            return fp
+    return None
