@@ -8,7 +8,22 @@ class ToStrJSONEncoder(json.JSONEncoder):
 
 
 def obj2str(obj):
-    return json.dumps(obj, indent=4, ensure_ascii=False, sort_keys=True, cls=ToStrJSONEncoder)
+    def walk(_obj):
+        try:
+            _json = getattr(_obj, '__json__', None)
+        except:
+            _json = None
+        if _json is not None:
+            _obj = _json()
+        if isinstance(_obj, dict):
+            result = {}
+            for k, v in _obj.items():
+                result[k] = walk(v)
+            return result
+        else:
+            return _obj
+
+    return json.dumps(walk(obj), indent=2, ensure_ascii=False, sort_keys=True, cls=ToStrJSONEncoder)
 
 
 def get_data_or_value(data, expression=None):
