@@ -2,7 +2,7 @@ from importlib import metadata
 from .attr import Object
 
 
-def iter_plugins(name: str, group: str = 'plugins', ignore: set | None = None, **kwargs):
+def iter_plugins(name: str, group: str = 'plugins', ignore = None, **kwargs): # ignore: set | None
     for ep in metadata.entry_points(group=name.partition('.')[0] + '.' + group, **kwargs):
         if not ignore or ep.name not in ignore:
             yield Object(name=ep.name, module=ep.module, value=ep.load())
