@@ -19,8 +19,7 @@ class Startup:
             self._lock.release()
 
     def start(self):
-        t = threading.Thread(target=self.__target)
-        t.start()
+        threading.Thread(target=self.__target).start()
 
     def __target(self):
         with self._lock:
