@@ -24,3 +24,25 @@ def is_html(s):
     if begin is not None:
         return s[begin:begin + len(html_marker)] == html_marker
     return False
+
+
+_redirect_html_format = """
+<!DOCTYPE html>
+<html>
+<head>
+    <meta charset="UTF-8">
+    <meta content="always" name="referrer">
+    <script>
+    var timeout = 0;
+    ;setTimeout(function () {
+        window.location.replace("%s")
+    }, timeout);
+    window.opener = null;</script>
+    <noscript>
+        <META http-equiv="refresh" content="0;URL='%s'">
+    </noscript>
+""".replace('\n', '')
+
+
+def get_redirect_html(url):
+    return _redirect_html_format % (url, url)
