@@ -1,6 +1,6 @@
 import json
-from pathlib import Path
 from mimetypes import MimeTypes
+from .res import path_mime_data
 
 mimetypes = MimeTypes()
 
@@ -14,7 +14,7 @@ for k, v in custom_types.items():
     mimetypes.add_type(k, v)
 
 # https://github.com/patrickmccallum/mimetype-io/blob/master/src/mimeData.json
-with open(Path(__file__).resolve().parent / 'res' / 'mimeData.json', 'rb') as f:
+with open(path_mime_data, 'rb') as f:
     data_list = json.load(f)
 for data in data_list:
     if data['fileTypes']:
